@@ -3,10 +3,17 @@ require(knitr)
 opts_chunk$set(comment='')
 require(PSAboot)
 
-boot.M <- 50 # Change for the final version
+## ------------------------------------------------------------------------
+boot.M <- 10
+
+## ----BootSizeWarning, echo=FALSE, results='asis'-------------------------
+if(boot.M < 100) {
+	cat(paste0('**NOTE: This vignette uses ', boot.M, ' bootstrap samples. It is ',
+	    'generally recommended to use at least 100 bootstrap samples or more for final publication.**'))
+}
 
 ## ----install, eval=FALSE-------------------------------------------------
-#  devtools::install_github('PSAboot','jbryer')
+#  devtools::install_github('jbryer/PSAboot')
 
 ## ----defineCustomFunction------------------------------------------------
 boot.matching.1to3 <- function(Tr, Y, X, X.trans, formu, ...) {
@@ -17,7 +24,7 @@ boot.matching.1to3 <- function(Tr, Y, X, X.trans, formu, ...) {
 data(lalonde, package='MatchIt')
 table(lalonde$treat)
 
-## ----lalonde.boot, cache=TRUE--------------------------------------------
+## ----lalonde.boot, cache=FALSE-------------------------------------------
 lalonde.formu <- treat ~ age + I(age^2) + educ + I(educ^2) + black +
 	hispan + married + nodegree + re74  + I(re74^2) + re75 + I(re75^2) +
 	re74 + re75
@@ -43,7 +50,7 @@ boxplot(boot.lalonde)
 ## ----lalonde.matrixplot--------------------------------------------------
 matrixplot(boot.lalonde)
 
-## ----lalonde.balance, cache=TRUE-----------------------------------------
+## ----lalonde.balance, cache=FALSE----------------------------------------
 lalonde.bal <- balance(boot.lalonde)
 lalonde.bal
 
@@ -63,7 +70,7 @@ covs <- tutoring[,c('Gender', 'Ethnicity', 'Military', 'ESL', 'EdMother', 'EdFat
 
 table(tutoring$treatbool)
 
-## ----tutoring.psaboot, cache=TRUE----------------------------------------
+## ----tutoring.psaboot, cache=FALSE---------------------------------------
 tutoring.boot <- PSAboot(Tr=tutoring$treatbool, 
 						 Y=tutoring$Grade, 
 						 X=covs, 
